@@ -46,6 +46,9 @@ class SharedData:
 
         # Symbols collections metadata
         self.metadata = {}
+
+        # static metadata
+        self.static = pd.DataFrame([])
         
         Logger.log.debug('Initializing SharedData %s,%s,%s DONE!' % (user,database,mode))
 
@@ -62,10 +65,38 @@ class SharedData:
             self.metadata[collection] = Metadata(collection,\
                 mode=self.mode,\
                 user=self.user)
+            self.mergeUpdate(self.metadata[collection].static)            
         return self.metadata[collection]
 
     def getSymbols(self, collection):        
         return self.getMetadata(collection).static.index.values
+
+    def mergeUpdate(self,newdf):
+        ddidx = newdf.index.duplicated()
+        if ddidx.any():
+            newdf = newdf[~newdf.index.duplicated(keep='first')]            
+            Logger.log.warning('Metadata merge duplicated index for new dataframe!')
+        
+        ddidx = self.static.index.duplicated()        
+        if ddidx.any():
+            self.static = self.static[~self.static.index.duplicated(keep='first')]            
+            Logger.log.warning('Metadata merge duplicated index for static dataframe!')
+
+        newcolsidx = ~newdf.columns.isin(self.static.columns)
+        if newcolsidx.any():
+            newcols = newdf.columns[newcolsidx]
+            for c in newcols:
+                self.static.loc[:,c] = newdf[c]                
+
+        newidx = ~newdf.index.isin(self.static.index)
+        if newidx.any():
+            self.static = self.static.reindex(index=self.static.index.union(newdf.index))
+
+        newcol = ~newdf.columns.isin(self.static.columns)
+        if newcol.any():
+            self.static = self.static.reindex(columns=self.static.columns.union(newdf.columns))
+            
+        self.static.update(newdf)
   
     def SubscribeRealTime(self):
         SharedDataRealTime.Subscribe(self)
\ No newline at end of file
